The ``linchpin ssh`` command provides a simple way to connect to provisioned
systems. Instead of looking for the system in the inventory file and writing
an ssh command, it is easy as writing ``linchpin ssh``, hitting <TAB><TAB>
and selecting the system. The double tab works with linchpin auto-complete
that can be enabled by running: ``eval "$(_LINCHPIN_COMPLETE=source linchpin)"``

The SSH command will look for the latest inventory generated by Linchpin for
connection information.

.. code-block:: bash

    $ linchpin ssh --help
    Usage: linchpin ssh [OPTIONS] TARGET

    Options:
      -h, --help  Show this message and exit.

